function [ys, check] = ALEstim_pet_modi_steadystate(ys,ex0)
global M_ 

%% Here I load the values of the deep parameters in a loop.
NumberOfParameters = M_.param_nbr;                            % Number of deep parameters.
for i = 1:NumberOfParameters                                  % Loop...
  paramname = deblank(M_.param_names(i,:));                   %    Get the name of parameter i. 
  eval([ paramname ' = M_.params(' int2str(i) ');']);         %    Get the value of parameter i.
end   

check = 0; % why??

%% END OF THE FIRST MODEL INDEPENDENT BLOCK.

%% THIS BLOCK IS MODEL SPECIFIC.
%%


etamc = lambdamc/(lambdamc-1);%transforming markups to demand elasticities used in the programs
etami = lambdami/(lambdami-1);%transforming markups to demand elasticities used in the programs

% kappamc=kappad; p edit
% kappami=kappad;
% kappax=kappad;

%foreign terms of trade  = Nominal exhange rate times foreign price divided by domestic price
gammaf  = 1;

%equation (3.3)
piebar = mu/muz;
piecbar = piebar;  %CPI inflation

%equation (3.2)
Rbar = (piebar*muz-tauk*beta)/((1-tauk)*beta);  %New version 2003-11-28

%equation (3.15)
Rfbar = nubar*Rbar +(1-nubar);

%equation (3.7)
gammacd = ( (1-omegac) + omegac*(etamc/(etamc-1))^(1-etac) )^(1/(1-etac));

%equation (3.8)
gammacmc = ( (1-omegac)*((etamc-1)/etamc)^(1-etac) + omegac )^(1/(1-etac));%New version 2003-11-19

%equation (3.9)
gammaid = ( (1-omegai) + omegai*(etami/(etami-1))^(1-etai) )^(1/(1-etai));

%equation (3.10)
gammaimi = ( (1-omegai)*((etami-1)/etami)^(1-etai) + omegai )^(1/(1-etai)); %New version 2003-11-19

%equation (3.11)
gammamcd = ( ((1-omegac)+omegac*(etamc/(etamc-1))^(1-etac))/((1-omegac)*((etamc-1)/etamc)^(1-etac)+omegac) )^(1/(1-etac));
gammamcd = etamc/(etamc - 1);

%equation (3.12)
gammamid = ( ((1-omegai)+omegai*(etami/(etami-1))^(1-etai))/((1-omegai)*((etami-1)/etami)^(1-etai)+omegai) )^(1/(1-etai));
gammamid = etami/(etami - 1);

%checking that the calculations of the relative prices are consistent
if abs(gammacd/gammacmc-gammamcd) > 1e-9;
   error('The steady state calculations of the consumption relative prices are not correct...');
elseif abs(gammaid/gammaimi-gammamid) > 1e-9;
   error('The steady state calculations of the investment relative prices are not correct...');
end;
% if abs(gammacd/gammacmc-gammamcd) > 1e-9;
%     check=1; %set failure indicator
%     return; %return without updating steady states
% elseif abs(gammaid/gammaimi-gammamid) > 1e-9;
%     check=1; %set failure indicator
%     return; %return without updating steady states
% end;   
%equation (3.6)
Pkprime = gammaid;

%equation (3.14)
rkbar = (muz*Pkprime-beta*(1-delta)*Pkprime)/((1-tauk)*beta);

%solution for wbarRfbar from equation 16
wbarRfbar = (lambdaf*( (1/(1-sharek))^(1-sharek) )*( (1/sharek)^sharek )*rkbar^sharek)^(1/(sharek-1));

%solution for wbar
wbar = wbarRfbar/Rfbar;

%solution for k/H from equation 13
koverH = (sharek/(1-sharek))*muz*wbar*Rfbar/rkbar;


%Profit for imported firms
PiimcPc = omegac*(gammamcd-1)*gammacmc^etac;
PiimiPi = omegai*(gammamid-1)*gammaimi^etai;
if PiimcPc < 0 | PiimiPi < 0;
   error('Profits for the importing firm are negative, should not be possible...');
end;

%definition of composite coefficients, equation (3.25)
D1 = (1-omegac)*gammacd^etac+omegac*gammacmc^etac;
D2 = ((1-ratiog)/lambdaf)*(muz^-sharek)*(koverH^sharek) - ...
     ((1-omegai)*(gammaid^etai)+omegai*(gammaimi^etai))*(1-(1-delta)/muz)*koverH;
D3 = ( ((1-tauy)*(1/lambdaw)*(wbar/(1+tauw)))/Al )^(1/sigmal);
D4 = ((muz-beta*b)/((1+tauc)*(muz-b)))*(gammacd^-1);

%equation (3.26)
Hbar = (D3*(D4^(1/sigmal)*((D2/D1)^(-1/sigmal))))^(sigmal/(1+sigmal));
cbar = (D2/D1)*Hbar;
phiz = (1/cbar)*D4;

%equation (3.27)
ybar = (1/lambdaf)*(muz^-sharek)*(koverH^sharek)*Hbar;



%equation (3.18)
phi = (lambdaf-1)*ybar;
if abs(phi-((lambdaf-1)/lambdaf)*(muz^-sharek)*(koverH^sharek)*Hbar) > 1e-6;
   error('Something is wrong with the steady state calcuations of phi');
end;

%solution for kbar
kbar = koverH*Hbar;

%equation (3.20)
ibar = (1-(1-delta)/muz)*kbar;

%equation (3.28)
gbar = ratiog*ybar;

%Import: cons & invest
cmbar = omegac*(gammacmc^etac)*cbar;
imbar = omegai*(gammaimi^etai)*ibar;

%equation (3.24) (xtilde = cxbar + ixbar)
xtilde = cmbar+imbar;
zbar = xtilde; %export equal import in steady state
xbar = xtilde;
% NOTE that xtilde = ystarbar since 
% 1. (cmbar + imbar = cxbar + ixbar)
% 2. zstar = z
% 3. Px = Pstar
% 
% cmbar + imbar = omegac*(gammacmc^etac)*cbar + omegai*(gammaimi^etai)*ibar
% cxbar + ixbar = (gammaxstar^-etaf)*ystar*(zstar/z)
%


%domestic: cons & invest
cdbar = (1-omegac)*(gammacd^etac)*cbar;
idbar = (1-omegai)*(gammaid^etai)*ibar;

%NOTE #1: ChangeHere 2004-03-23 by JL: We have that mbar = nubar*wbar*Hbar+qbar
%since piebar*muz/mu = 1. The calibration of qbar and mbar from eqs 27 and
%28 are problematic since when Aq is fixed, then when sigmaq change in the
%estimation, then the qbar/mbar ratio in the model can be very different from
%0.4, which is roughly the relevant value in the data. Therefore, we change
%the code here to calibrate qbar/mbar rather than letting the ratio of qbar/mbar
%change considerably in the estimation.
%NOTE #2: We change the notation here so that Aq now refer to the desired ratio
%between cash and M3 in the steady state. WARNING FOR THIS CHANGE!!!

%old equations
%equation 27
%qbar = (Aq/((1-tauk)*phiz*(Rbar-1)))^(1/sigmaq);
%equation 28
%mbar = piebar*muz*(nubar*wbar*Hbar+qbar)/mu;%Corrected 2003-12-22 by JL

%new equations
if nubar ~= 0;
   mbar = (nubar*wbar*Hbar)/(1-Aq); 
   qbar = Aq*mbar;
else;
   disp('Warning: nubar is zero, assume that mbar is a small number ...');
   mbar = 1e-6;
   qbar = Aq*mbar;
end;

if (qbar/mbar) > 1;
   error('Steady state: Warning -> MO is bigger than M3');
end;

%computing some alternative measures to verify that the steady-state
%calculations are not necessarily incorrect.

ybar1 = (muz^-sharek)*(kbar^sharek)*Hbar^(1-sharek)-phi;
ybar2 = (cdbar+cmbar) + (idbar+imbar) + gbar + xtilde - zbar;
ybar3 = (wbar*Rfbar*Hbar+rkbar*kbar*(1/muz));

if abs(ybar-ybar1) > 1e-9 | abs(ybar-ybar2) > 1e-9 | abs(ybar-ybar3) > 1e-9;
   %error('The steady state calculations are not correct.');
end;

% Get ratios.

% disp('steady state ratios for various aggregates in the model - should match those in the data.');
ratioc  =(cdbar+cmbar)/ybar;
ratioi  =(idbar+imbar)/ybar;
ratiox = xtilde/ybar;
ratioz = zbar/ybar;

if abs(1-(ratiog+ratiox+ratioc+ratioi-ratioz)) > 1e-9;
   ratiog+ratiox+ratioc+ratioi-ratioz
   error('SteadyState: The sum of the GDP component ratios do not sum to unity.');
end;

mcbar= ((1/(1-sharek))^(1-sharek))*((1/sharek)^sharek)*(rkbar^sharek)*((wbar*(nubar*Rbar+1-nubar))^(1-sharek) );

if abs(mcbar-(1/lambdaf)) > 1e-6;
    error('SteadyState: Something is wrong with marginal cost in SS.');
end

profif_bar = (gammamcd - gammaf)*cmbar + (gammamid - gammaf)*imbar; 

%Check the stationarized budget contraint in SS
budgetSS = (1 - Rbar)*mbar + cbar*gammacd + ibar*gammaid - (1 - Rbar)*qbar - rkbar*kbar*(1/muz)  - wbar*Hbar + gbar ... 
           - profif_bar;

if abs(budgetSS) > 1e-6;
   %error('SteadyState: Budget restriction does not hold in SS.');
end;


%Parameters to the wage equation
  bw     = (lambdaw*sigmal - (1-lambdaw))/((1-beta*xiw)*(1-xiw)) ;
  eta0   =  bw*xiw;
  eta1   = (sigmal*lambdaw - bw*(1+beta*(xiw^2)));
  eta2   =  bw*beta*xiw;
  eta3   = -bw*xiw;
  eta4   =  bw*beta*xiw;
  eta5   =  bw*kappaw*xiw;
  eta6   = -bw*beta*kappaw*xiw;
  eta7   =  (1-lambdaw);
  eta8   = -(1-lambdaw)*sigmal;
  eta9   = -(1-lambdaw)*(tauy/(1-tauy));
  eta10  = -(1-lambdaw)*(tauw/(1+tauw));
  eta11  = -(1-lambdaw);

  %%
data_pid = 400*(piebar-1)*piebar;
data_wp = 100*log(muz);
data_c = 100*log(muz);
data_i = 100*log(muz);
data_R = 400*(Rbar-1)*Rbar; 
data_y = 100*log(muz);
data_pic = 400*(piebar-1)*piebar;
data_pii = 400*(piebar-1)*piebar;
% data_ystar = 100*log(muz);
% data_pistar = 400*(piebar-1)*piebar;
% data_Rstar = 400*(Rbar-1)*Rbar;
% data_x = 100*log(muz);
% data_m = 100*log(muz);
%%
ys = zeros( M_.endo_nbr, 1);
ys(55) = data_pid;
ys(56) = data_wp;
ys(57) = data_c;
ys(58) = data_i;
ys(59) = data_R;
ys(60) = data_y;
ys(61) = data_x;
ys(62) = data_m;
ys(63) = data_pic;
ys(64) = data_pii;
ys(65) = data_ystar;
ys(66) = data_pistar;
ys(67) = data_Rstar;
ys(68) = 0;

check = 0;  %Dynare Switch indicating good steady state            
%% END OF THE MODEL SPECIFIC BLOCK.

%% Here we define the steady state values of the endogenous variables of
%% the model.
%%
NumberOfEndogenousVariables = M_.endo_nbr;                    % Number of endogenous variables.
ys = zeros(NumberOfEndogenousVariables,1);                    % Initialization of ys (steady state).
for i = 1:NumberOfEndogenousVariables                         % Loop...
  varname = deblank(M_.endo_names(i,:));                      %    Get the name of endogenous variable i.                     
  eval(['ys(' int2str(i) ') = ' varname ';']);                %    Get the steady state value of this variable.
end            
%% END OF THE SECOND MODEL INDEPENDENT BLOCK.